@@ -3,7 +3,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 use Carp;
 use Data::Compare;
@@ -24,10 +24,13 @@ BEGIN {
 
     eval {
         require Devel::Trace::Subs;
+    };
+
+    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
+    if (! defined &trace){
         *trace = sub {};
     }
 };
@@ -72,7 +75,7 @@ sub all {
     $self->run($p);
 }
 sub has {
-    
+
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -231,7 +234,7 @@ sub order {
 #
 
 sub add_functionality {
-   
+
     trace() if $ENV{TRACE};
     
     my $self = shift;
@@ -240,7 +243,6 @@ sub add_functionality {
     $self->_config($p);
     
     my $to_add = $self->{params}{add_functionality};
-    
     my $in_prod = $self->{params}{add_functionality_prod};
 
     my @allowed = qw(
@@ -281,7 +283,6 @@ sub add_functionality {
                         ? $INC{'Devel/Examine/Subs/Engine.pm'}
                         : 'lib/Devel/Examine/Subs/Engine.pm';
                       },
-
     );
 
     my $caller = (caller)[1];
@@ -304,8 +305,31 @@ sub add_functionality {
     }
 
     my $file = $dt{$to_add}->();
+    my $copy = $self->{params}{copy};
 
-    my $des = Devel::Examine::Subs->new(
+    if ($copy) {
+        copy $file, $copy or die $!;
+        $file = $copy;
+    }
+
+    my $sub_name;
+    
+    if ($code[0] =~ /sub\s+(\w+)/){
+        $sub_name = $1;
+    }
+    else {
+        croak "couldn't extract the sub name";
+    }
+
+    my $des = Devel::Examine::Subs->new(file => $file);
+
+    my $existing_subs = $des->all;
+
+    if (grep { $sub_name eq $_ } @$existing_subs) {
+        croak "the sub you're trying to add already exists";
+    }
+
+    $des = Devel::Examine::Subs->new(
                                     file => $file,
                                     engine => 'objects', 
                                     post_proc => [qw(subs end_of_last_sub)],
@@ -322,15 +346,6 @@ sub add_functionality {
 
     $rw->splice(file => $file, insert => \@code, line => $start_writing);
 
-    my $sub_name;
-
-    if ($code[0] =~ /sub\s+(\w+)\s+\{/){
-        $sub_name = $1;
-    }
-    else {
-        croak "add_functionality() couldn't extract the sub name.";
-    }
-
     my @insert = ("        $sub_name => \\&$sub_name,");
 
     my @ret = $rw->splice(
@@ -793,7 +808,21 @@ sub _write_file {
     my $contents = $self->{write_file_contents};
 
     return if ! $file;
-    $file = $copy if $copy;
+
+    if ($self->{params}{directory} && ! -d $copy){
+        warn "\n\nin directory mode, all files are copied to the dir named " .
+             "in the copy param, which is $copy\n\n";
+
+        mkdir $copy or croak "can't create directory $copy";
+    }
+    if ($copy && -d $copy){
+        copy $file, $copy;
+        my $filename = basename $file;
+        $file = "$copy/$filename";
+    }
+    elsif ($copy) {
+        $file = $copy;
+    }
 
     my $write_response;
 
@@ -1180,7 +1209,7 @@ sub _engine {
 # pod
 #
 
-sub _pod{} #vim placeholder 
+sub _pod{1;} #vim placeholder
 1; 
 __END__
 
@@ -1868,6 +1897,8 @@ Travis-CI: L<https://travis-ci.org/stevieb9/devel-examine-subs>
 
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=Devel-Examine-Subs>
 
+Coverage: L<https://coveralls.io/github/stevieb9/devel-examine-subs>
+
 =head1 DEBUGGING
 
 If C<Devel::Trace::Subs> is installed, you can configure stack tracing.
@@ -1913,7 +1944,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of either: the GNU General Public License as published by the
