@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 use Carp;
 use Data::Dumper;
@@ -13,15 +13,18 @@ use File::Copy;
 
 BEGIN {
 
-    # we need to do some trickery for DTS due to a circular install
+    # we need to do some trickery for DTS due to circular referencing,
+    # which broke CPAN installs.
 
     eval {
         require Devel::Trace::Subs;
+    };
+
+    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
-        # override DTS's trace() function if necessary
+    if (! defined &trace){
         *trace = sub {};
     }
 };
@@ -53,7 +56,6 @@ sub _dt {
         inject_after => \&inject_after,
         dt_test => \&dt_test,
         _test => \&_test,
-        _test_print => \&_test_print,
         _test_bad => \&_test_bad,
     };
 
@@ -82,16 +84,6 @@ sub _test {
         return {a => 1};
     };
 }
-sub _test_print {
-    
-    trace() if $ENV{TRACE};
-
-    return sub {
-        
-        trace() if $ENV{TRACE};
-        print "Hello, world!\n";
-    };
-}
 sub all {
     
     trace() if $ENV{TRACE};
@@ -147,7 +139,7 @@ sub missing {
 
         my $file = $p->{file};
         my $search = $p->{search};
- 
+
         if ($search && ! $p->{regex}){
             $search = "\Q$search";
         }
@@ -217,32 +209,13 @@ sub objects {
         return if not ref($struct) eq 'ARRAY';
 
         my $file = $p->{file};
-        my $search = $p->{search};
-
-        if ($search && ! $p->{regex}){
-            $search = "\Q$search";
-        }
 
         my $lines;
 
-        if ($search){
-            my $des = Devel::Examine::Subs->new({
-                                            file => $file, 
-                                            search => $search
-                                        });
-            $lines = $des->lines;
-        }
-
-        my $des_sub;
-        my %obj_hash;
-        my @obj_array;
+        my ($des_sub, %obj_hash, @obj_array);
 
         for my $sub (@$struct){
 
-            if ($lines){
-                $sub->{lines_with} = $lines->{$sub->{name}};
-            }
-
             $des_sub
               = Devel::Examine::Subs::Sub->new($sub, $sub->{name});
 
@@ -439,10 +412,9 @@ sub inject_after {
         return \@processed;
     };                        
 }
+sub _vim_placeholder {1;}
 1;
 
-sub _vim_placeholder {}
-
 __END__
 
 =head1 NAME
@@ -530,7 +502,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of either: the GNU General Public License as published by the Free
