@@ -3,21 +3,25 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 use Carp;
 use Data::Dumper;
 
 BEGIN {
 
-    # we need to do some trickery for DTS due to a circular install
+    # we need to do some trickery for DTS due to circular referencing,
+    # which broke CPAN installs.
 
     eval {
         require Devel::Trace::Subs;
+    };
+
+    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
+    if (! defined &trace){
         *trace = sub {};
     }
 };
@@ -81,19 +85,9 @@ sub subs {
         my $s = $struct;
         my @subs;
 
-        my $search = $p->{search};
-
-        if ($search && ! $p->{regex}){
-            $search = "\Q$search";
-        }
-
         for my $f (keys %$s){
         
             for my $sub (keys %{$s->{$f}{subs}}){
-                
-                if ($search && $sub eq $search){
-                    next;
-                }
                 $s->{$f}{subs}{$sub}{start}++;
                 $s->{$f}{subs}{$sub}{end}++;
                 $s->{$f}{subs}{$sub}{name} = $sub;
@@ -212,29 +206,17 @@ sub objects {
 
         for my $sub (@$struct){
 
-            # if the name of the callback method is mistyped in the
-            # dispatch table, this will be triggered
-
             $des_sub
               = Devel::Examine::Subs::Sub->new($sub, $sub->{name});
 
-            #FIXME: this eval catch catches bad dispatch and "not a hashref"
-
-            if ($@){
-                print "dispatch table in engine has a mistyped function " .
-                      "value\n\n";
-                confess $@;
-            }
-
             push @return, $des_sub;
         }
 
         return \@return;
     };
 }
+sub _vim_placeholder {1;}
 1;
-sub _vim_placeholder {}
-
 __END__
 
 =head1 NAME
@@ -292,7 +274,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of either: the GNU General Public License as published by the Free
