@@ -3,21 +3,25 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 use Carp;
 use Data::Dumper;
 
 BEGIN {
 
-    # we need to do some trickery for DTS due to a circular install
+    # we need to do some trickery for DTS due to circular referencing,
+    # which broke CPAN installs.
 
     eval {
         require Devel::Trace::Subs;
+    };
+
+    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
+    if (! defined &trace){
         *trace = sub {};
     }
 };
@@ -182,10 +186,6 @@ sub inject {
 
                 $i++;
 
-                if ($e =~ /^\n/){
-                    push @new_file, "\n";
-                }
-
                 my $indent = '';
 
                 my $count = $i;
@@ -280,12 +280,8 @@ sub remove {
         $p->{write_file_contents} = \@file;
     }
 }
-
+sub _vim_placeholder {1;}
 1;
-
-
-sub _vim_placeholder {}
-
 __END__
 
 =head1 NAME
@@ -366,7 +362,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of either: the GNU General Public License as published by the Free
