@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.58';
+our $VERSION = '1.59';
 
 use Data::Dumper;
 
@@ -13,10 +13,13 @@ BEGIN {
 
     eval {
         require Devel::Trace::Subs;
+    };
+
+    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
+    if (! defined &trace){
         *trace = sub {};
     }
 };
